==> core_models-0.1.0.gem: app/controllers/core_models/base/timespans_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::TimespansController < CoreModelsController
    # GET /base/timespans
    # GET /base/timespans.json
    def index
      @base_timespans = Base::Timespan.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_timespans }
      end
    end

    # GET /base/timespans/1
    # GET /base/timespans/1.json
    def show
      @base_timespan = Base::Timespan.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_timespan }
      end
    end

    # GET /base/timespans/new
    # GET /base/timespans/new.json
    def new
      @base_timespan = Base::Timespan.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_timespan }
      end
    end

    # GET /base/timespans/1/edit
    def edit
      @base_timespan = Base::Timespan.find(params[:id])
    end

    # POST /base/timespans
    # POST /base/timespans.json
    def create
      @base_timespan = Base::Timespan.new(params[:base_timespan])

      respond_to do |format|
        if @base_timespan.save
          format.html { redirect_to @base_timespan, :notice => 'Timespan was successfully created.' }
          format.json { render :json => @base_timespan, :status => :created, :location => @base_timespan }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_timespan.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/timespans/1
    # PUT /base/timespans/1.json
    def update
      @base_timespan = Base::Timespan.find(params[:id])

      respond_to do |format|
        if @base_timespan.update_attributes(params[:base_timespan])
          format.html { redirect_to @base_timespan, :notice => 'Timespan was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_timespan.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/timespans/1
    # DELETE /base/timespans/1.json
    def destroy
      @base_timespan = Base::Timespan.find(params[:id])
      @base_timespan.destroy

      respond_to do |format|
        format.html { redirect_to base_timespans_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/base/timespans_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::TimespansController < CoreModelsController
    # GET /base/timespans
    # GET /base/timespans.json
    def index
      @base_timespans = Base::Timespan.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_timespans }
      end
    end

    # GET /base/timespans/1
    # GET /base/timespans/1.json
    def show
      @base_timespan = Base::Timespan.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_timespan }
      end
    end

    # GET /base/timespans/new
    # GET /base/timespans/new.json
    def new
      @base_timespan = Base::Timespan.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_timespan }
      end
    end

    # GET /base/timespans/1/edit
    def edit
      @base_timespan = Base::Timespan.find(params[:id])
    end

    # POST /base/timespans
    # POST /base/timespans.json
    def create
      @base_timespan = Base::Timespan.new(params[:base_timespan])

      respond_to do |format|
        if @base_timespan.save
          format.html { redirect_to @base_timespan, :notice => 'Timespan was successfully created.' }
          format.json { render :json => @base_timespan, :status => :created, :location => @base_timespan }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_timespan.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/timespans/1
    # PUT /base/timespans/1.json
    def update
      @base_timespan = Base::Timespan.find(params[:id])

      respond_to do |format|
        if @base_timespan.update(params[:base_timespan])
          format.html { redirect_to @base_timespan, :notice => 'Timespan was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_timespan.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/timespans/1
    # DELETE /base/timespans/1.json
    def destroy
      @base_timespan = Base::Timespan.find(params[:id])
      @base_timespan.destroy

      respond_to do |format|
        format.html { redirect_to base_timespans_url }
        format.json { head :no_content }
      end
    end
  end
end
